@@ -14,6 +14,11 @@ class Migration(migrations.Migration):
         migrations.AlterField(
             model_name='phonedevice',
             name='key',
-            field=models.CharField(default=django_otp.util.random_hex, help_text='Hex-encoded secret key', max_length=40, validators=[key_validator]),
+            field=models.CharField(
+                default=django_otp.util.random_hex,
+                help_text='Hex-encoded secret key',
+                max_length=40,
+                validators=[key_validator]
+            ),
         ),
     ]
